@@ -3,4 +3,4 @@ from plugable import Plugable
 
 class PrefixListDatasource(Plugable):
     def fetch(self):
-        pass
+        raise NotImplementedError()
